@@ -20,6 +20,8 @@
 #include "edit_shortcuts_dialog.h"
 #include "shortcuts_manager.h"
 
+#include "whats_new_controller.h"
+
 #include <ctime>
 #include <algorithm>
 #include <QApplication>
@@ -73,6 +75,14 @@ MainWindowViewer::MainWindowViewer()
 {
     loadConfiguration();
     setupUI();
+    afterLaunchTasks();
+}
+
+void MainWindowViewer::afterLaunchTasks()
+{
+    WhatsNewController whatsNewController;
+
+    whatsNewController.showWhatsNewIfNeeded(this);
 }
 
 MainWindowViewer::~MainWindowViewer()
@@ -86,10 +96,10 @@ MainWindowViewer::~MainWindowViewer()
     delete openFolderAction;
     delete openLatestComicAction;
     delete saveImageAction;
-    delete openPreviousComicAction;
-    delete openNextComicAction;
-    delete prevAction;
-    delete nextAction;
+    delete openComicOnTheLeftAction;
+    delete openComicOnTheRightAction;
+    delete goToPageOnTheLeftAction;
+    delete goToPageOnTheRightAction;
     delete adjustHeightAction;
     delete adjustWidthAction;
     delete leftRotationAction;
@@ -259,39 +269,39 @@ void MainWindowViewer::createActions()
     saveImageAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(SAVE_IMAGE_ACTION_Y));
     connect(saveImageAction, SIGNAL(triggered()), this, SLOT(saveImage()));
 
-    openPreviousComicAction = new QAction(tr("Previous Comic"), this);
-    openPreviousComicAction->setIcon(QIcon(":/images/viewer_toolbar/openPrevious.png"));
-    openPreviousComicAction->setToolTip(tr("Open previous comic"));
-    openPreviousComicAction->setDisabled(true);
-    openPreviousComicAction->setData(OPEN_PREVIOUS_COMIC_ACTION_Y);
-    openPreviousComicAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(OPEN_PREVIOUS_COMIC_ACTION_Y));
-    connect(openPreviousComicAction, SIGNAL(triggered()), this, SLOT(openPreviousComic()));
+    openComicOnTheLeftAction = new QAction(tr("Previous Comic"), this);
+    openComicOnTheLeftAction->setIcon(QIcon(":/images/viewer_toolbar/openPrevious.png"));
+    openComicOnTheLeftAction->setToolTip(tr("Open previous comic"));
+    openComicOnTheLeftAction->setDisabled(true);
+    openComicOnTheLeftAction->setData(OPEN_PREVIOUS_COMIC_ACTION_Y);
+    openComicOnTheLeftAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(OPEN_PREVIOUS_COMIC_ACTION_Y));
+    connect(openComicOnTheLeftAction, &QAction::triggered, this, &MainWindowViewer::openLeftComic);
 
-    openNextComicAction = new QAction(tr("Next Comic"), this);
-    openNextComicAction->setIcon(QIcon(":/images/viewer_toolbar/openNext.png"));
-    openNextComicAction->setToolTip(tr("Open next comic"));
-    openNextComicAction->setDisabled(true);
-    openNextComicAction->setData(OPEN_NEXT_COMIC_ACTION_Y);
-    openNextComicAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(OPEN_NEXT_COMIC_ACTION_Y));
-    connect(openNextComicAction, SIGNAL(triggered()), this, SLOT(openNextComic()));
+    openComicOnTheRightAction = new QAction(tr("Next Comic"), this);
+    openComicOnTheRightAction->setIcon(QIcon(":/images/viewer_toolbar/openNext.png"));
+    openComicOnTheRightAction->setToolTip(tr("Open next comic"));
+    openComicOnTheRightAction->setDisabled(true);
+    openComicOnTheRightAction->setData(OPEN_NEXT_COMIC_ACTION_Y);
+    openComicOnTheRightAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(OPEN_NEXT_COMIC_ACTION_Y));
+    connect(openComicOnTheRightAction, &QAction::triggered, this, &MainWindowViewer::openRightComic);
 
-    prevAction = new QAction(tr("&Previous"), this);
-    prevAction->setIcon(QIcon(":/images/viewer_toolbar/previous.png"));
-    prevAction->setShortcutContext(Qt::WidgetShortcut);
-    prevAction->setToolTip(tr("Go to previous page"));
-    prevAction->setDisabled(true);
-    prevAction->setData(PREV_ACTION_Y);
-    prevAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(PREV_ACTION_Y));
-    connect(prevAction, SIGNAL(triggered()), viewer, SLOT(prev()));
+    goToPageOnTheLeftAction = new QAction(tr("&Previous"), this);
+    goToPageOnTheLeftAction->setIcon(QIcon(":/images/viewer_toolbar/previous.png"));
+    goToPageOnTheLeftAction->setShortcutContext(Qt::WidgetShortcut);
+    goToPageOnTheLeftAction->setToolTip(tr("Go to previous page"));
+    goToPageOnTheLeftAction->setDisabled(true);
+    goToPageOnTheLeftAction->setData(PREV_ACTION_Y);
+    goToPageOnTheLeftAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(PREV_ACTION_Y));
+    connect(goToPageOnTheLeftAction, SIGNAL(triggered()), viewer, SLOT(left()));
 
-    nextAction = new QAction(tr("&Next"), this);
-    nextAction->setIcon(QIcon(":/images/viewer_toolbar/next.png"));
-    nextAction->setShortcutContext(Qt::WidgetShortcut);
-    nextAction->setToolTip(tr("Go to next page"));
-    nextAction->setDisabled(true);
-    nextAction->setData(NEXT_ACTION_Y);
-    nextAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(NEXT_ACTION_Y));
-    connect(nextAction, SIGNAL(triggered()), viewer, SLOT(next()));
+    goToPageOnTheRightAction = new QAction(tr("&Next"), this);
+    goToPageOnTheRightAction->setIcon(QIcon(":/images/viewer_toolbar/next.png"));
+    goToPageOnTheRightAction->setShortcutContext(Qt::WidgetShortcut);
+    goToPageOnTheRightAction->setToolTip(tr("Go to next page"));
+    goToPageOnTheRightAction->setDisabled(true);
+    goToPageOnTheRightAction->setData(NEXT_ACTION_Y);
+    goToPageOnTheRightAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(NEXT_ACTION_Y));
+    connect(goToPageOnTheRightAction, SIGNAL(triggered()), viewer, SLOT(right()));
 
     adjustHeightAction = new QAction(tr("Fit Height"), this);
     adjustHeightAction->setIcon(QIcon(":/images/viewer_toolbar/toHeight.png"));
@@ -412,6 +422,7 @@ void MainWindowViewer::createActions()
     doubleMangaPageAction->setData(DOUBLE_MANGA_PAGE_ACTION_Y);
     doubleMangaPageAction->setShortcut(ShortcutsManager::getShortcutsManager().getShortcut(DOUBLE_MANGA_PAGE_ACTION_Y));
     connect(doubleMangaPageAction, SIGNAL(triggered()), viewer, SLOT(doubleMangaPageSwitch()));
+    connect(doubleMangaPageAction, &QAction::triggered, this, &MainWindowViewer::doubleMangaPageSwitch);
 
     goToPageAction = new QAction(tr("Go To"), this);
     goToPageAction->setIcon(QIcon(":/images/viewer_toolbar/goto.png"));
@@ -552,13 +563,13 @@ void MainWindowViewer::createToolBars()
 #endif
 
     comicToolBar->addAction(saveImageAction);
-    comicToolBar->addAction(openPreviousComicAction);
-    comicToolBar->addAction(openNextComicAction);
+    comicToolBar->addAction(openComicOnTheLeftAction);
+    comicToolBar->addAction(openComicOnTheRightAction);
 
     comicToolBar->addSeparator();
 
-    comicToolBar->addAction(prevAction);
-    comicToolBar->addAction(nextAction);
+    comicToolBar->addAction(goToPageOnTheLeftAction);
+    comicToolBar->addAction(goToPageOnTheRightAction);
     comicToolBar->addAction(goToPageAction);
 
     comicToolBar->addSeparator();
@@ -615,12 +626,12 @@ void MainWindowViewer::createToolBars()
     viewer->addAction(openAction);
     viewer->addAction(openFolderAction);
     viewer->addAction(saveImageAction);
-    viewer->addAction(openPreviousComicAction);
-    viewer->addAction(openNextComicAction);
+    viewer->addAction(openComicOnTheLeftAction);
+    viewer->addAction(openComicOnTheRightAction);
     YACReader::addSperator(viewer);
 
-    viewer->addAction(prevAction);
-    viewer->addAction(nextAction);
+    viewer->addAction(goToPageOnTheLeftAction);
+    viewer->addAction(goToPageOnTheRightAction);
     viewer->addAction(goToPageAction);
     viewer->addAction(adjustHeightAction);
     viewer->addAction(adjustWidthAction);
@@ -706,8 +717,8 @@ void MainWindowViewer::createToolBars()
     viewMenu->addAction(showMagnifyingGlassAction);
 
     auto goMenu = new QMenu(tr("Go"));
-    goMenu->addAction(prevAction);
-    goMenu->addAction(nextAction);
+    goMenu->addAction(goToPageOnTheLeftAction);
+    goMenu->addAction(goToPageOnTheRightAction);
     goMenu->addAction(goToPageAction);
     goMenu->addSeparator();
     goMenu->addAction(setBookmarkAction);
@@ -822,9 +833,6 @@ void MainWindowViewer::open()
 
 void MainWindowViewer::open(QString path, ComicDB &comic, QList<ComicDB> &siblings)
 {
-    //currentComicDB = comic;
-    //siblingComics = siblings;
-
     QFileInfo fi(path);
 
     if (!comic.info.title.isNull() && !comic.info.title.toString().isEmpty())
@@ -832,31 +840,23 @@ void MainWindowViewer::open(QString path, ComicDB &comic, QList<ComicDB> &siblin
     else
         setWindowTitle("YACReader - " + fi.fileName());
 
+    viewer->setMangaWithoutStoringSetting(comic.info.manga.toBool());
+    doubleMangaPageAction->setChecked(comic.info.manga.toBool());
+
     viewer->open(path, comic);
     enableActions();
     int index = siblings.indexOf(comic);
+    updatePrevNextActions(index > 0, index + 1 < siblings.count());
 
     optionsDialog->setFilters(currentComicDB.info.brightness, currentComicDB.info.contrast, currentComicDB.info.gamma);
-
-    if (index > 0)
-        openPreviousComicAction->setDisabled(false);
-    else
-        openPreviousComicAction->setDisabled(true);
-
-    if (index + 1 < siblings.count())
-        openNextComicAction->setDisabled(false);
-    else
-        openNextComicAction->setDisabled(true);
 }
 
-void MainWindowViewer::open(QString path, qint64 comicId, qint64 libraryId)
+void MainWindowViewer::open(QString path, qint64 comicId, qint64 libraryId, OpenComicSource source)
 {
-    //QString pathFile = QCoreApplication::arguments().at(1);
     currentDirectory = path;
-    //quint64 comicId = QCoreApplication::arguments().at(2).split("=").at(1).toULongLong();
-    //libraryId = QCoreApplication::arguments().at(3).split("=").at(1).toULongLong();
+
     this->libraryId = libraryId;
-    //	this->path=path;
+    this->source = source;
 
     enableActions();
 
@@ -864,7 +864,7 @@ void MainWindowViewer::open(QString path, qint64 comicId, qint64 libraryId)
     YACReaderLocalClient client;
     int tries = 1;
     bool success = false;
-    while (!(success = client.requestComicInfo(libraryId, currentComicDB, siblingComics)) && tries != 0)
+    while (!(success = client.requestComicInfo(libraryId, currentComicDB, siblingComics, source)) && tries != 0)
         tries--;
 
     if (success) {
@@ -881,8 +881,10 @@ void MainWindowViewer::open(QString path, qint64 comicId, qint64 libraryId)
 
 void MainWindowViewer::openComicFromPath(QString pathFile)
 {
+    doubleMangaPageAction->setChecked(Configuration::getConfiguration().getDoubleMangaPage());
     openComic(pathFile);
     isClient = false; //this method is used for direct openings
+    updatePrevNextActions(!previousComicPath.isEmpty(), !nextComicPath.isEmpty());
 }
 
 //isClient shouldn't be modified when a siblinig comic is opened
@@ -947,7 +949,7 @@ void MainWindowViewer::openFolderFromPath(QString pathDir, QString atFileName)
     d.setSorting(QDir::Name | QDir::IgnoreCase | QDir::LocaleAware);
     QStringList list = d.entryList();
 
-    qSort(list.begin(), list.end(), naturalSortLessThanCI);
+    std::sort(list.begin(), list.end(), naturalSortLessThanCI);
     int i = 0;
     foreach (QString path, list) {
         if (path.endsWith(atFileName))
@@ -978,8 +980,8 @@ void MainWindowViewer::saveImage()
 void MainWindowViewer::enableActions()
 {
     saveImageAction->setDisabled(false);
-    prevAction->setDisabled(false);
-    nextAction->setDisabled(false);
+    goToPageOnTheLeftAction->setDisabled(false);
+    goToPageOnTheRightAction->setDisabled(false);
     adjustHeightAction->setDisabled(false);
     adjustWidthAction->setDisabled(false);
     goToPageAction->setDisabled(false);
@@ -1010,8 +1012,8 @@ void MainWindowViewer::enableActions()
 void MainWindowViewer::disableActions()
 {
     saveImageAction->setDisabled(true);
-    prevAction->setDisabled(true);
-    nextAction->setDisabled(true);
+    goToPageOnTheLeftAction->setDisabled(true);
+    goToPageOnTheRightAction->setDisabled(true);
     adjustHeightAction->setDisabled(true);
     adjustWidthAction->setDisabled(true);
     goToPageAction->setDisabled(true);
@@ -1030,8 +1032,8 @@ void MainWindowViewer::disableActions()
     setBookmarkAction->setDisabled(true);
     showBookmarksAction->setDisabled(true);
     showInfoAction->setDisabled(true); //TODO enable goTo and showInfo (or update) when numPages emited
-    openPreviousComicAction->setDisabled(true);
-    openNextComicAction->setDisabled(true);
+    openComicOnTheLeftAction->setDisabled(true);
+    openComicOnTheRightAction->setDisabled(true);
     showDictionaryAction->setDisabled(true);
     showFlowAction->setDisabled(true);
 }
@@ -1228,11 +1230,11 @@ void MainWindowViewer::processReset()
 {
     if (isClient) {
         if (siblingComics.count() > 1) {
-            bool openNextB = openNextComicAction->isEnabled();
-            bool openPrevB = openPreviousComicAction->isEnabled();
+            bool openNextB = openComicOnTheRightAction->isEnabled();
+            bool openPrevB = openComicOnTheLeftAction->isEnabled();
             disableActions();
-            openNextComicAction->setEnabled(openNextB);
-            openPreviousComicAction->setEnabled(openPrevB);
+            openComicOnTheRightAction->setEnabled(openNextB);
+            openComicOnTheLeftAction->setEnabled(openPrevB);
         } else
             disableActions();
     } else
@@ -1252,8 +1254,8 @@ void MainWindowViewer::setUpShortcutsManagement()
                                                      openLatestComicAction,
                                                      openFolderAction,
                                                      saveImageAction,
-                                                     openPreviousComicAction,
-                                                     openNextComicAction });
+                                                     openComicOnTheLeftAction,
+                                                     openComicOnTheRightAction });
 
     allActions << tmpList;
 
@@ -1327,6 +1329,7 @@ void MainWindowViewer::setUpShortcutsManagement()
                                                  << doublePageAction
                                                  << doubleMangaPageAction
                                                  << adjustToFullSizeAction
+                                                 << fitToPageAction
                                                  << increasePageZoomAction
                                                  << decreasePageZoomAction
                                                  << resetZoomAction);
@@ -1383,8 +1386,8 @@ void MainWindowViewer::setUpShortcutsManagement()
 
     editShortcutsDialog->addActionsGroup(tr("Reading"), QIcon(":/images/shortcuts_group_reading.png"),
                                          tmpList = QList<QAction *>()
-                                                 << nextAction
-                                                 << prevAction
+                                                 << goToPageOnTheRightAction
+                                                 << goToPageOnTheLeftAction
                                                  << setBookmarkAction
                                                  << showBookmarksAction
                                                  << autoScrollForwardAction
@@ -1406,6 +1409,16 @@ void MainWindowViewer::setUpShortcutsManagement()
     ShortcutsManager::getShortcutsManager().registerActions(allActions);
 }
 
+void MainWindowViewer::doubleMangaPageSwitch()
+{
+    if (isClient) {
+        int index = siblingComics.indexOf(currentComicDB);
+        updatePrevNextActions(index > 0, index + 1 < siblingComics.size());
+    } else {
+        updatePrevNextActions(!previousComicPath.isEmpty(), !nextComicPath.isEmpty());
+    }
+}
+
 void MainWindowViewer::toggleFitToWidthSlider()
 {
     int y;
@@ -1497,6 +1510,7 @@ void MainWindowViewer::openNextComic()
             currentComicDB = siblingComics.at(currentIndex + 1);
             open(currentDirectory + currentComicDB.path, currentComicDB, siblingComics);
         }
+
         return;
     }
     if (!nextComicPath.isEmpty()) {
@@ -1504,6 +1518,24 @@ void MainWindowViewer::openNextComic()
     }
 }
 
+void MainWindowViewer::openLeftComic()
+{
+    if (viewer->getIsMangaMode()) {
+        openNextComic();
+    } else {
+        openPreviousComic();
+    }
+}
+
+void MainWindowViewer::openRightComic()
+{
+    if (viewer->getIsMangaMode()) {
+        openPreviousComic();
+    } else {
+        openNextComic();
+    }
+}
+
 void MainWindowViewer::getSiblingComics(QString path, QString currentComic)
 {
     QDir d(path);
@@ -1530,8 +1562,7 @@ void MainWindowViewer::getSiblingComics(QString path, QString currentComic)
 #endif
     d.setSorting(QDir::Name | QDir::IgnoreCase | QDir::LocaleAware);
     QStringList list = d.entryList();
-    qSort(list.begin(), list.end(), naturalSortLessThanCI);
-    //std::sort(list.begin(),list.end(),naturalSortLessThanCI);
+    std::sort(list.begin(), list.end(), naturalSortLessThanCI);
     int index = list.indexOf(currentComic);
     if (index == -1) //comic not found
     {
@@ -1558,15 +1589,13 @@ void MainWindowViewer::getSiblingComics(QString path, QString currentComic)
     previousComicPath = nextComicPath = "";
     if (index > 0) {
         previousComicPath = path + "/" + list.at(index - 1);
-        openPreviousComicAction->setDisabled(false);
-    } else
-        openPreviousComicAction->setDisabled(true);
+    }
 
     if (index + 1 < list.count()) {
         nextComicPath = path + "/" + list.at(index + 1);
-        openNextComicAction->setDisabled(false);
-    } else
-        openNextComicAction->setDisabled(true);
+    }
+
+    updatePrevNextActions(index > 0, index + 1 < list.count());
 }
 
 void MainWindowViewer::dropEvent(QDropEvent *event)
@@ -1671,3 +1700,46 @@ void MainWindowViewer::sendComic()
             retries--;
     }
 }
+
+void MainWindowViewer::updatePrevNextActions(bool thereIsPrevious, bool thereIsNext)
+{
+    if (thereIsPrevious) {
+        if (viewer->getIsMangaMode()) {
+            openComicOnTheRightAction->setDisabled(false);
+        } else {
+            openComicOnTheLeftAction->setDisabled(false);
+        }
+    } else {
+        if (viewer->getIsMangaMode()) {
+            openComicOnTheRightAction->setDisabled(true);
+        } else {
+            openComicOnTheLeftAction->setDisabled(true);
+        }
+    }
+
+    if (thereIsNext) {
+        if (viewer->getIsMangaMode()) {
+            openComicOnTheLeftAction->setDisabled(false);
+        } else {
+            openComicOnTheRightAction->setDisabled(false);
+        }
+    } else {
+        if (viewer->getIsMangaMode()) {
+            openComicOnTheLeftAction->setDisabled(true);
+        } else {
+            openComicOnTheRightAction->setDisabled(true);
+        }
+    }
+
+    if (viewer->getIsMangaMode()) {
+        openComicOnTheLeftAction->setToolTip(tr("Open next comic"));
+        openComicOnTheRightAction->setToolTip(tr("Open previous comic"));
+        goToPageOnTheLeftAction->setToolTip(tr("Go to next page"));
+        goToPageOnTheRightAction->setToolTip(tr("Go to previous page"));
+    } else {
+        openComicOnTheLeftAction->setToolTip(tr("Open previous comic"));
+        openComicOnTheRightAction->setToolTip(tr("Open next comic"));
+        goToPageOnTheLeftAction->setToolTip(tr("Go to previous page"));
+        goToPageOnTheRightAction->setToolTip(tr("Go to next page"));
+    }
+}
