@@ -223,14 +223,18 @@ qulonglong LibraryCreator::insertFolders()
     auto _database = QSqlDatabase::database(_databaseConnection);
     QList<Folder>::iterator i;
     int currentId = 0;
+    Folder currentParent;
     for (i = _currentPathFolders.begin(); i != _currentPathFolders.end(); ++i) {
         if (!(i->knownId)) {
             i->setFather(currentId);
+            i->setManga(currentParent.isManga());
             currentId = DBHelper::insert(&(*i), _database); //insertFolder(currentId,*i);
             i->setId(currentId);
         } else {
             currentId = i->id;
         }
+
+        currentParent = *i;
     }
     return currentId;
 }
@@ -311,6 +315,7 @@ void LibraryCreator::insertComic(const QString &relativePath, const QFileInfo &f
         }
 
         comic.parentId = _currentPathFolders.last().id;
+        comic.info.manga = _currentPathFolders.last().isManga();
         DBHelper::insert(&comic, _database);
     }
 }
@@ -328,8 +333,8 @@ void LibraryCreator::update(QDir dirS)
     dirS.setSorting(QDir::Name | QDir::IgnoreCase | QDir::LocaleAware);
     QFileInfoList listSFiles = dirS.entryInfoList();
 
-    qSort(listSFolders.begin(), listSFolders.end(), naturalSortLessThanCIFileInfo);
-    qSort(listSFiles.begin(), listSFiles.end(), naturalSortLessThanCIFileInfo);
+    std::sort(listSFolders.begin(), listSFolders.end(), naturalSortLessThanCIFileInfo);
+    std::sort(listSFiles.begin(), listSFiles.end(), naturalSortLessThanCIFileInfo);
 
     QFileInfoList listS;
     listS.append(listSFolders);
@@ -346,8 +351,8 @@ void LibraryCreator::update(QDir dirS)
     //QLOG_TRACE() << "END Getting info from DB" << dirS.absolutePath();
 
     QList<LibraryItem *> listD;
-    qSort(folders.begin(), folders.end(), naturalSortLessThanCILibraryItem);
-    qSort(comics.begin(), comics.end(), naturalSortLessThanCILibraryItem);
+    std::sort(folders.begin(), folders.end(), naturalSortLessThanCILibraryItem);
+    std::sort(comics.begin(), comics.end(), naturalSortLessThanCILibraryItem);
     listD.append(folders);
     listD.append(comics);
     //QLOG_DEBUG() << "---------------------------------------------------------";
@@ -646,7 +651,7 @@ void ThumbnailCreator::create()
         if (_coverPage > _numPages) {
             _coverPage = 1;
         }
-        qSort(fileNames.begin(), fileNames.end(), naturalSortLessThanCI);
+        std::sort(fileNames.begin(), fileNames.end(), naturalSortLessThanCI);
         int index = order.indexOf(fileNames.at(_coverPage - 1));
 
         if (_target == "") {
